@@ -2,6 +2,7 @@ import requests
 
 from skimage import io
 from io import BytesIO
+from typing import Dict
 
 DOMAIN = "tellusxdp.com"
 
@@ -10,12 +11,12 @@ class TellusApiClient():
     def __init__(self, token: str):
         self.token = token
 
-    def get_blend(self, zoom: int, xtile: int, ytile: int):
+    def get_blend(self, zoom: int, xtile: int, ytile: int, params: Dict = {}):
         url: str = 'https://gisapi.{}/blend/{}/{}/{}.png'.format(
             DOMAIN, zoom, xtile, ytile)
         headers: dict = {
             "Authorization": "Bearer " + self.token
         }
 
-        r = requests.get(url, headers=headers)
+        r = requests.get(url, headers=headers, params=params)
         return io.imread(BytesIO(r.content))
